Description Usage Arguments Examples
This function allows you to add the Ultrachord theme to your ggplot graphics.
1 | theme_ultrachord(base_size = 11, base_family = "", panel_grid_minor = TRUE)
|
base_size |
\[type: numeric, default: 11\] The default font size. |
base_family |
\[type: string, default: ""\] The name of a family of text or font. |
panel_grid_minor |
\[type: logical, default: TRUE\] Boolean allows turning minor grids on or off. |
1 2 3 4 5 6 7 8 9 10 11 12 13 | iris |>
ggplot2::ggplot(ggplot2::aes(x = Sepal.Length, y = Sepal.Width)) +
ggplot2::geom_point(ggplot2::aes(color = Species, shape = Species)) +
ggplot2::labs(title = "Iris data", subtitle = "Classic data", x = "Sepal Length", y = "Sepal Width") +
ggplot2::facet_grid(~ Species) +
ultraPlot::theme_ultrachord()
data.frame(year = time(nhtemp), tmps = as.matrix(nhtemp)) |>
ggplot2::ggplot(ggplot2::aes(x = year, y = tmps)) +
ggplot2::geom_line() +
# ggplot2::geom_hline(yintercept = 0, size = 1, colour = "#333333") +
ggplot2::labs(title = "New Hampshire yearly temperatures", subtitle = "Collected between 1912 and 1971", x = "Year", y = "Average temperature") +
ultraPlot::theme_ultrachord()
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.